@@ -1,5 +1,5 @@
 from .imutils import *
 from .boxutils import *
 from .dataset import split_files,split_list,split_dir,split_train_val_imagefolder,split_train_val
-from .data_aug import img_aug,det_aug
+from .data_aug import img_aug,det_aug,random_float_generator
 from .ops import bbox_ops,polygon_ops,pil_ops,opencv_ops
\ No newline at end of file
